# PhosphoDisco (PhDc)
A python package for finding co-regulated phospho sites from phosphoproteomics and proteomics data.   


## Description
PhDc uses optimized clustering to find co-regulated phosphosite modules. Then, PhDc uses protein and phosphoprotein abundance data from kinases and phosphatases to nominate module regulators. It can also use sample annotation data to identify modules significantly correlated with clinical variables. 

See the docs at [https://github.com/ruggleslab/phosphodisco](https://github.com/ruggleslab/phosphodisco)
